@@ -2,11 +2,11 @@
 #'
 #' Make a sequence of data into a normalised Wave object.
 #'
-#' @param left Data for  audio channel
+#' @param left Data for mono audio channel
 #' @param samp.rate Sampling rate for Wave object
 #' @param bit Bit depth of Wave object
 #' @param remove.offset If TRUE any DC offset is removed
-#' @param normalise IF TRUE the output Wave is normalised using tuneR
+#' @param normalise IF TRUE the output Wave is normalised to -1:1
 #' @return A mono Wave object.
 #' @examples
 #' pattern <- seq(from=-1, to=1, length.out=100)
@@ -22,9 +22,9 @@ data2Wave <- function(left, samp.rate=44100, bit=16, remove.offset=TRUE, normali
     a <- mean(left)
     left <- left-a
   }
-  wave <- tuneR::Wave(left=left, right = numeric(0), samp.rate=samp.rate, bit=bit)
   if (normalise == TRUE) {
-    wave <- tuneR::normalize(wave)
+    left <- left/max(abs(left))
   }
+  wave <- tuneR::Wave(left=left, right = numeric(0), samp.rate=samp.rate, bit=bit)
   return(wave)
 }
